==> haskell-loop-0.3.0-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 loop
version:              0.3.0
visibility:           public
id:                   loop-0.3.0-8O3oZUnJ6qzF1EfCjfHxIb
key:                  loop-0.3.0-8O3oZUnJ6qzF1EfCjfHxIb
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/loop
synopsis:             Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.

    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.

category:             Control
abi:                  f5dd6869dc1f88f388a55ca5ac97e01d
exposed:              True
exposed-modules:      Control.Loop Control.Loop.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/loop-0.3.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/loop-0.3.0
hs-libraries:         HSloop-0.3.0-8O3oZUnJ6qzF1EfCjfHxIb
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html:         /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loop-0.3.0-131-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 loop
version:              0.3.0
visibility:           public
id:                   loop-0.3.0-ChqQlljHNscLUXTAqbRWjQ
key:                  loop-0.3.0-ChqQlljHNscLUXTAqbRWjQ
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/loop
synopsis:             Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.

    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.

category:             Control
abi:                  c760cb0aee525e735e856ea092d43774
exposed:              True
exposed-modules:      Control.Loop Control.Loop.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/loop-0.3.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/loop-0.3.0
hs-libraries:         HSloop-0.3.0-ChqQlljHNscLUXTAqbRWjQ
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html:         /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
